!+
! Module: backcorr_mod
!
! Authors:  Didier Barret, Natalie Webb - CESR
!          
! Description: Makes a background spectrum appropriate to the accumulation region used for a given source spectrum
! 
! Comments: 
! 
! $Id: module.f90,v 1.6 1998/05/27 13:45:39 gvacanti Exp $
!- 
module backcorr_mod

  use dal
  use cal
  use param  
  use metatask_mod
  use arfgen_f_mod
  use make_backcorr_mod
  use errorHandling
  use caloaldefs

  implicit none 

  private 

  public backcorr


contains 

  !---------------------------------------------------------------------
  subroutine backcorr
  !---------------------------------------------------------------------


! infilesrc : input source spectrum from which the extraction region is going to read
! infilebkg : input background spectrum to be corrected
! outset : output backcorr corrected spectrum


  character (len=4096)            :: infilesrc, infilebkg, outfile
!  logical (kind=boolean) :: false

!=======================================================================
! Get ALL INPUT PARAMETERS for the task
!=======================================================================
 
  call message(AppMsg,Sparse,"Backcorr reading the parameter file")

  infilebkg=stringParameter("bkgspectrumset")  
  infilesrc=stringParameter("srcspectrumset")  
  outfile=stringParameter("outbkgspectrumset")  

  call message(AppMsg,Sparse,"Backcorr... running")

! The big change betweeen versions 1.X and 2.0 is that arfgen nows 
! gets the information about the extraction region with the data subspace

! Calls arfgen for the source region

  call openParameters("arfgen")
  call setParameter("spectrumset",trim(infilesrc))
  call setParameter("arfset","arf_in_src.arf")
  call setParameter("withbadpixcorr",.false.)
  call task(arfgen)

  call message(AppMsg,Sparse,"Backcorr: 1st call to arfgen done")


! Calls arfgen for the background region

  call setParameter("spectrumset",trim(infilebkg))
  call setParameter("arfset","arf_in_bkg.arf")
  call setParameter("withbadpixcorr",.false.)
  call task(arfgen)
  call message(AppMsg,Sparse,"Backcorr: 2nd call to arfgen done")

! Now calls the second task make_backcorr which actually performs
! the normalisation of the input background

  call OpenParameters("make_backcorr")
  call setParameter("arfsrcset","arf_in_src.arf")
  call setParameter("arfbkgset","arf_in_bkg.arf")
  call setParameter("inset",trim(infilebkg))
  call setParameter("outset",trim(outfile))
  call task(make_backcorr)
  call message(AppMsg,Sparse,"Backcorr... end")

! Now delete temporary local arf files

  call deleteDataSet("arf_in_src.arf")
  call deleteDataSet("arf_in_bkg.arf")
  call deleteDataSet("rawpixellist.ds")
  call message(AppMsg,Sparse,"Deleting temporary files .. done")

  end subroutine backcorr


end module backcorr_mod
